import { Box } from "@chakra-ui/react";
import BatchForm from "../components/form";
import { usersRequestList } from "@/app/lib/users/action";
import { getAssignPriorityRequestList } from "@/app/lib/assignment-priority/action";
import { prepareUsersDropdown } from "@/utils/common";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import { IbcInterface } from "@/types/settings/ibc/ibc";

const Create = async () => {
  const [users, ibcs, assignmentPriority] = await Promise.all([
    usersRequestList({ "pagination": "false" }),
    getIbcRequestList({ pagination: 'false' }),
    getAssignPriorityRequestList({ pagination: 'false' }),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for ibc dropdown
  const ibcsDropdown =
    ibcs?.data && ibcs?.data.length > 0
      ? ibcs?.data.map((ibc: IbcInterface) => ({
        label: `${ibc.area_name}`,
        value: ibc.id,
      }))
      : [];

  // Prepare data for assign priority dropdown
  const assignPriorityDropdown =
    assignmentPriority?.data && assignmentPriority?.data?.length > 0
      ? assignmentPriority?.data.map((item: any) => ({
        label: item?.name,
        value: item?.id,
      }))
      : [];

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      <BatchForm
        usersDropdown={usersDropdown}
        ibcDropdown={ibcsDropdown}
        assignPriorityOption={assignPriorityDropdown}
      />
    </Box>
  );
};

export default Create;
